searchData={"items":[{"type":"module","title":"Cron","doc":"`Cron` parses cron expressions and calculates execution timings.\n\nExpressions with 6 and 5 fields are expected. The variant with 6 fields adds a\nfield for seconds at the first position. The variant with 5 fields corresponds\nto the standard Unix behavior. The field `second` will be set to `0` when\n`Cron.new/1` gets 5 fields.\n\nPossible values for the fields:\n```\n+----------- second (0 - 59)\n| +--------- minute (0 - 59)\n| | +------- hour (0 - 23)\n| | | +----- day of the month (1 - 31)\n| | | | +--- month (1 - 12)\n| | | | | +- day of the week (0 - 6, SUN - SAT)\n| | | | | |\n* * * * * *\n```\n\nA field may contain an asterisk `*`, which means any of the possible values.\n\nA range of values can be specified with an `-`.\nExample: `10-15`.\n\nA `/` can be used to setup steps. The value before the `/` specifies the start\nvalue and the value behind the `/` specifies the step width.\nExample: `*/2`, `4/2`.\n\nMultiple values can be declared with a `,` separated list without any\nwhitespace.\nExample: `1,5,10-15,*/2`.\n\nThe fields `month` and `day_of_week` are also accept names. Month accepts\n`Jan`, `Feb`, `Mar`, `Apr`, `May`, `Jun`, `Jul`, `Aug`, `Sep`. `Oct`, `Nov`\nand `Dez`. The case does not matter.\n\n`day_of_week` accepts `Sun`, `Mon`, `Tue`, `Wed`, `Thu`, `Fri` and `Sat`. The\ncase does not matter. Keep in mind that `Sun` is equal to `0` and `Sat` is\nequal to `6`.\n\nAll `Cron` functions are working with `NaiveDateTime` or `DateTime` that are\nusing the `Calendar.ISO`. Any `DateTime` must have the time zone `Etc/UTC`.","ref":"Cron.html"},{"type":"module","title":"Examples - Cron","doc":"A cron expression that triggers daily at 12:00:00\n\n    iex> \"0 12 * * *\"\n    ...> |> Cron.new!()\n    ...> |> Cron.next(~U[2021-12-06 22:11:44Z])\n    ~U[2021-12-07 12:00:00Z]\n\n`Cron.stream/2` calculates multiple values. The following cron expression\ntriggers ever 30 minutes from 12 to 14 at the first day in a month.\n\n    iex> \"0 */30 12-14 1 * *\"\n    ...> |> Cron.new!()\n    ...> |> Cron.stream(from: ~U[2021-12-06 11:22:33Z])\n    ...> |> Enum.take(8)\n    [\n      ~N[2022-01-01 12:00:00],\n      ~N[2022-01-01 12:30:00],\n      ~N[2022-01-01 13:00:00],\n      ~N[2022-01-01 13:30:00],\n      ~N[2022-01-01 14:00:00],\n      ~N[2022-01-01 14:30:00],\n      ~N[2022-02-01 12:00:00],\n      ~N[2022-02-01 12:30:00]\n    ]","ref":"Cron.html#module-examples"},{"type":"type","title":"Cron.expression/0","doc":"","ref":"Cron.html#t:expression/0"},{"type":"function","title":"Cron.match?/2","doc":"Returns true if the given `datetime` matches the `cron`.\n\nThe function truncates the precision of the given `datetime` to seconds.\n\nExamples\n\n    iex> cron = Cron.new!(\"0 * * * *\")\n    iex> Cron.match?(cron, ~U[2021-11-13 06:41:39Z])\n    false\n    iex> Cron.match?(cron, ~U[2021-11-13 13:00:00Z])\n    true\n    iex> Cron.match?(cron, ~U[2021-11-13 13:00:00.999Z])\n    true\n\n    iex> \"* * * * * *\" |> Cron.new!() |> Cron.match?()\n    true","ref":"Cron.html#match?/2"},{"type":"type","title":"Cron.millisecond/0","doc":"","ref":"Cron.html#t:millisecond/0"},{"type":"function","title":"Cron.new/1","doc":"Returns an `:ok` tuple with a cron struct for the given expression string. If\nthe expression is invalid an `:error` will be returned.\n\nWill accept expression with 6 (including `second`) and 5 (`second: 0`) fields.","ref":"Cron.html#new/1"},{"type":"function","title":"Examples - Cron.new/1","doc":"iex> {:ok, cron} = Cron.new(\"1 2 3 * *\")\n    iex> cron\n    #Cron<1 2 3 * *>\n\n    iex> {:ok, cron} = Cron.new(\"0 1 2 3 * *\")\n    iex> cron\n    #Cron<0 1 2 3 * *>\n\n    iex> Cron.new(\"66 1 2 3 * *\")\n    {:error, second: \"66\"}","ref":"Cron.html#new/1-examples"},{"type":"function","title":"Cron.new!/1","doc":"Same as `new/1`, but raises an `ArgumentError` exception in case of an invalid\nexpression.","ref":"Cron.html#new!/1"},{"type":"function","title":"Cron.next/2","doc":"Returns the next execution datetime.\n\nIf the given `datetime` matches `cron`, then also the following datetime is\nreturning. That means the resulting datetime is always greater than the given.\nThe function truncates the precision of the given `datetime` to seconds.","ref":"Cron.html#next/2"},{"type":"function","title":"Examples - Cron.next/2","doc":"iex> {:ok, cron} = Cron.new(\"0 0 0 * * *\")\n    iex> Cron.next(cron, ~U[2022-01-01 12:00:00Z])\n    ~U[2022-01-02 00:00:00Z]\n    iex> Cron.next(cron, ~U[2022-01-02 00:00:00Z])\n    ~U[2022-01-03 00:00:00Z]\n    iex> Cron.next(cron, ~U[2022-01-02 00:00:00.999Z])\n    ~U[2022-01-03 00:00:00Z]","ref":"Cron.html#next/2-examples"},{"type":"function","title":"Cron.next_while/3","doc":"Returns an `:ok` tuple with the next execution datetime for which fun returns\na truthy value.\n\nIf no datetime can be found, an `:error` will be returned.\n\nThe function truncates the precision of the given `datetime` to seconds.","ref":"Cron.html#next_while/3"},{"type":"function","title":"Examples - Cron.next_while/3","doc":"iex> {:ok, cron} = Cron.new(\"0 0 29 2 *\")\n    iex> Cron.next_while(cron, fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, ~N[2044-02-29 00:00:00]}\n    iex> Cron.next_while(\n    ...>   cron, ~U[2044-02-29 00:00:00Z], fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, ~U[2072-02-29 00:00:00Z]}\n\n    iex> {:ok, cron} = Cron.new(\"0 0 1 1 *\")\n    iex> Cron.next_while(cron, fn _ -> false end)\n    :error","ref":"Cron.html#next_while/3-examples"},{"type":"function","title":"Cron.next_while!/3","doc":"Same as `next_while/3`, but raises a `RuntimeError` exception in case no\nexecution datetime can be found.","ref":"Cron.html#next_while!/3"},{"type":"function","title":"Cron.previous/2","doc":"Returns the previous execution datetime.\n\nIf the given `datetime` matches `cron`, then also the previous datetime is\nreturning. That means the resulting datetime is always lower than the given.\nThe function truncates the precision of the given `datetime` to seconds.","ref":"Cron.html#previous/2"},{"type":"function","title":"Examples - Cron.previous/2","doc":"iex> {:ok, cron} = Cron.new(\"0 0 0 * * *\")\n    iex> Cron.previous(cron, ~U[2022-01-01 12:00:00Z])\n    ~U[2022-01-01 00:00:00Z]\n    iex> Cron.previous(cron, ~U[2022-01-01 00:00:00Z])\n    ~U[2021-12-31 00:00:00Z]\n    iex> Cron.previous(cron, ~U[2022-01-01 00:00:00.999Z])\n    ~U[2021-12-31 00:00:00Z]","ref":"Cron.html#previous/2-examples"},{"type":"function","title":"Cron.previous_while/3","doc":"Returns an `:ok` tuple with the previous execution datetime for which fun\nreturns a truthy value.\n\nIf no datetime can be found, an `:error` will be returned.\n\nThe function truncates the precision of the given `datetime` to seconds.","ref":"Cron.html#previous_while/3"},{"type":"function","title":"Examples - Cron.previous_while/3","doc":"iex> {:ok, cron} = Cron.new(\"0 0 29 2 *\")\n    iex> Cron.previous_while(cron, fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, ~N[2016-02-29 00:00:00]}\n    iex> Cron.previous_while(\n    ...>   cron, ~U[2016-02-29 00:00:00Z], fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, ~U[1988-02-29 00:00:00Z]}\n\n    iex> {:ok, cron} = Cron.new(\"0 0 1 1 *\")\n    iex> Cron.previous_while(cron, fn _ -> false end)\n    :error","ref":"Cron.html#previous_while/3-examples"},{"type":"function","title":"Cron.previous_while!/3","doc":"Same as `previous_while/3`, but raises a `RuntimeError` exception in case no\nexecution datetime can be found.","ref":"Cron.html#previous_while!/3"},{"type":"type","title":"Cron.reason/0","doc":"","ref":"Cron.html#t:reason/0"},{"type":"function","title":"Cron.since/2","doc":"Same as `previous/3`, but returns the milliseconds since last execution\ndatetime.","ref":"Cron.html#since/2"},{"type":"function","title":"Examples - Cron.since/2","doc":"iex> {:ok, cron} = Cron.new(\"0 0 0 * * *\")\n    iex> Cron.since(cron, ~U[2022-01-02 00:00:00Z])\n    86_400_000\n    iex> Cron.since(cron, ~U[2022-01-02 00:01:00Z])\n    60_000\n    iex> Cron.since(cron, ~U[2022-01-02 00:01:00.999Z])\n    60_999\n    iex> Cron.since(cron, ~U[2022-01-02 00:00:00.999Z])\n    86_400_999","ref":"Cron.html#since/2-examples"},{"type":"function","title":"Cron.since_while/3","doc":"Same as `previous_while/3`, but returns the milliseconds since last execution\ndatetime.","ref":"Cron.html#since_while/3"},{"type":"function","title":"Examples - Cron.since_while/3","doc":"iex> {:ok, cron} = Cron.new(\"0 0 29 2 *\")\n    iex> Cron.since_while(\n    ...>   cron,\n    ...>   ~U[2022-01-01 00:00:00Z],\n    ...>   fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, 184_291_200_000}\n    iex> Cron.since_while(\n    ...>   cron,\n    ...>   ~U[2016-02-29 00:00:01.999Z],\n    ...>   fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, 1_999}\n\n    iex> {:ok, cron} = Cron.new(\"0 0 1 1 *\")\n    iex> Cron.since_while(cron, fn _ -> false end)\n    :error","ref":"Cron.html#since_while/3-examples"},{"type":"function","title":"Cron.since_while!/3","doc":"Same as `since_while!/3`, but raises a `RuntimeError` exception in case no\nexecution datetime can be found.","ref":"Cron.html#since_while!/3"},{"type":"function","title":"Cron.stream/2","doc":"Returns a `Stream` for the given `cron`.\n\nThe stream ends after the last execution datetime in the year 9000 or -9000.\n\nOptions:\n  * `:from` - the start datetime.\n    Defaults to `NaiveDateTime.utc_now(\"Etc/UTC\")`.\n\n  * `:oder` - `:asc` or `:desc` to get execution datetimes before or after\n    start datetime. Defaults to `:asc`.","ref":"Cron.html#stream/2"},{"type":"function","title":"Examples - Cron.stream/2","doc":"iex> cron = Cron.new!(\"0 0 12 1 * *\")\n    iex> stream = Cron.stream(cron, from: ~U[2022-06-05 00:00:00Z])\n    iex> Enum.take(stream, 3)\n    [\n      ~N[2022-07-01 12:00:00],\n      ~N[2022-08-01 12:00:00],\n      ~N[2022-09-01 12:00:00],\n    ]\n    iex> stream = Cron.stream(cron, from: ~U[2022-06-05 00:00:00Z], order: :desc)\n    iex> Enum.take(stream, 3)\n    [\n      ~N[2022-06-01 12:00:00],\n      ~N[2022-05-01 12:00:00],\n      ~N[2022-04-01 12:00:00],\n    ]\n    iex> stream = Cron.stream(cron, from: ~U[9000-10-05 00:00:00Z])\n    iex> Enum.take(stream, 3)\n    [\n      ~N[9000-11-01 12:00:00],\n      ~N[9000-12-01 12:00:00]\n    ]","ref":"Cron.html#stream/2-examples"},{"type":"type","title":"Cron.t/0","doc":"","ref":"Cron.html#t:t/0"},{"type":"function","title":"Cron.until/2","doc":"Same as `next/3`, but returns the milliseconds until next execution datetime.","ref":"Cron.html#until/2"},{"type":"function","title":"Examples - Cron.until/2","doc":"iex> {:ok, cron} = Cron.new(\"0 0 0 * * *\")\n    iex> Cron.until(cron, ~U[2022-01-01 12:00:00Z])\n    43200000\n    iex> Cron.until(cron, ~U[2022-01-02 00:00:00Z])\n    86400000\n    iex> Cron.until(cron, ~U[2022-01-02 00:00:00.999Z])\n    86399001","ref":"Cron.html#until/2-examples"},{"type":"function","title":"Cron.until_while/3","doc":"Same as `next_while/3`, but returns the milliseconds until next execution\ndatetime.","ref":"Cron.html#until_while/3"},{"type":"function","title":"Examples - Cron.until_while/3","doc":"iex> {:ok, cron} = Cron.new(\"0 0 29 2 *\")\n    iex> Cron.until_while(\n    ...>   cron,\n    ...>   ~U[2022-01-01 00:00:00Z],\n    ...>   fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, 699_321_600_000}\n    iex> Cron.until_while(\n    ...>   cron,\n    ...>   ~U[2044-02-28 23:59:59.100Z],\n    ...>   fn datetime -> Date.day_of_week(datetime) == 1 end)\n    {:ok, 900}\n\n    iex> {:ok, cron} = Cron.new(\"0 0 1 1 *\")\n    iex> Cron.until_while(cron, fn _ -> false end)\n    :error","ref":"Cron.html#until_while/3-examples"},{"type":"function","title":"Cron.until_while!/3","doc":"Same as `until_while!/3`, but raises a `RuntimeError` exception in case no\nexecution datetime can be found.","ref":"Cron.html#until_while!/3"},{"type":"module","title":"Poolder","doc":"Documentation for `Poolder`.","ref":"Poolder.html"},{"type":"function","title":"Poolder.call/3","doc":"Calls a function on a pooler process.","ref":"Poolder.html#call/3"},{"type":"function","title":"Examples - Poolder.call/3","doc":"iex> Poolder.call(pid, data, 1000)\n    {:ok, result}","ref":"Poolder.html#call/3-examples"},{"type":"behaviour","title":"Poolder.Batcher","doc":"","ref":"Poolder.Batcher.html"},{"type":"callback","title":"Poolder.Batcher.handle_batch/2","doc":"","ref":"Poolder.Batcher.html#c:handle_batch/2"},{"type":"callback","title":"Poolder.Batcher.handle_hibernate/1","doc":"","ref":"Poolder.Batcher.html#c:handle_hibernate/1"},{"type":"callback","title":"Poolder.Batcher.handle_init/1","doc":"","ref":"Poolder.Batcher.html#c:handle_init/1"},{"type":"behaviour","title":"Poolder.Dispatcher","doc":"","ref":"Poolder.Dispatcher.html"},{"type":"callback","title":"Poolder.Dispatcher.broadcast/2","doc":"","ref":"Poolder.Dispatcher.html#c:broadcast/2"},{"type":"callback","title":"Poolder.Dispatcher.call/3","doc":"","ref":"Poolder.Dispatcher.html#c:call/3"},{"type":"callback","title":"Poolder.Dispatcher.call/4","doc":"","ref":"Poolder.Dispatcher.html#c:call/4"},{"type":"callback","title":"Poolder.Dispatcher.cast/2","doc":"","ref":"Poolder.Dispatcher.html#c:cast/2"},{"type":"callback","title":"Poolder.Dispatcher.cast/3","doc":"","ref":"Poolder.Dispatcher.html#c:cast/3"},{"type":"callback","title":"Poolder.Dispatcher.count/1","doc":"","ref":"Poolder.Dispatcher.html#c:count/1"},{"type":"callback","title":"Poolder.Dispatcher.count_all/0","doc":"","ref":"Poolder.Dispatcher.html#c:count_all/0"},{"type":"callback","title":"Poolder.Dispatcher.list/1","doc":"","ref":"Poolder.Dispatcher.html#c:list/1"},{"type":"callback","title":"Poolder.Dispatcher.list_all/0","doc":"","ref":"Poolder.Dispatcher.html#c:list_all/0"},{"type":"module","title":"Poolder.Dispatcher.Default","doc":"","ref":"Poolder.Dispatcher.Default.html"},{"type":"function","title":"Poolder.Dispatcher.Default.broadcast/2","doc":"Sends a message to all registered pids in a group","ref":"Poolder.Dispatcher.Default.html#broadcast/2"},{"type":"function","title":"Poolder.Dispatcher.Default.call/3","doc":"Sends a synchronous call to a specific pid","ref":"Poolder.Dispatcher.Default.html#call/3"},{"type":"function","title":"Poolder.Dispatcher.Default.call/4","doc":"Performs a guarded call to a pid under specific group","ref":"Poolder.Dispatcher.Default.html#call/4"},{"type":"function","title":"Poolder.Dispatcher.Default.cast/2","doc":"Sends an asynchronous message to a specific pid","ref":"Poolder.Dispatcher.Default.html#cast/2"},{"type":"function","title":"Poolder.Dispatcher.Default.cast/3","doc":"Sends a guarded asynchronous message to a pid in a group","ref":"Poolder.Dispatcher.Default.html#cast/3"},{"type":"function","title":"Poolder.Dispatcher.Default.count/1","doc":"Returns the number of active workers in the given group","ref":"Poolder.Dispatcher.Default.html#count/1"},{"type":"function","title":"Poolder.Dispatcher.Default.count_all/0","doc":"Returns the number of active workers in all groups","ref":"Poolder.Dispatcher.Default.html#count_all/0"},{"type":"function","title":"Poolder.Dispatcher.Default.list/1","doc":"Returns a list of all active workers in the given group","ref":"Poolder.Dispatcher.Default.html#list/1"},{"type":"function","title":"Poolder.Dispatcher.Default.list_all/0","doc":"Returns a list of all active workers and their groups","ref":"Poolder.Dispatcher.Default.html#list_all/0"},{"type":"module","title":"Poolder.DynamicSupervisor","doc":"","ref":"Poolder.DynamicSupervisor.html"},{"type":"function","title":"Poolder.DynamicSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Poolder.DynamicSupervisor.html#child_spec/1"},{"type":"function","title":"Poolder.DynamicSupervisor.init/1","doc":"Callback implementation for  DynamicSupervisor.init/1 .","ref":"Poolder.DynamicSupervisor.html#init/1"},{"type":"function","title":"Poolder.DynamicSupervisor.start_link/2","doc":"","ref":"Poolder.DynamicSupervisor.html#start_link/2"},{"type":"module","title":"Poolder.Ets","doc":"","ref":"Poolder.Ets.html"},{"type":"function","title":"Poolder.Ets.new/2","doc":"Creates a new ETS table if it does not exist.","ref":"Poolder.Ets.html#new/2"},{"type":"behaviour","title":"Poolder.FactoryPool","doc":"Dynamic pool of grouped processes with fast lookup by group or pid.","ref":"Poolder.FactoryPool.html"},{"type":"behaviour","title":"Usage examples - Poolder.FactoryPool","doc":"# Start a worker under group :http\n  Poolder.FactoryPool.start_child(:http, {MyWorker, args})\n\n  # Synchronous call to specific pid\n  Poolder.FactoryPool.call(pid, :ping)\n\n  # Async message to a specific pid\n  Poolder.FactoryPool.cast(pid, :refresh)\n\n  # Broadcast to all workers in a group\n  Poolder.FactoryPool.broadcast(:http, :reload)\n\n  # Count active workers in a group\n  Poolder.FactoryPool.count(:http)","ref":"Poolder.FactoryPool.html#module-usage-examples"},{"type":"callback","title":"Poolder.FactoryPool.start_child/2","doc":"","ref":"Poolder.FactoryPool.html#c:start_child/2"},{"type":"callback","title":"Poolder.FactoryPool.terminate/1","doc":"","ref":"Poolder.FactoryPool.html#c:terminate/1"},{"type":"callback","title":"Poolder.FactoryPool.terminate_group/1","doc":"","ref":"Poolder.FactoryPool.html#c:terminate_group/1"},{"type":"behaviour","title":"Poolder.Monitor","doc":"","ref":"Poolder.Monitor.html"},{"type":"callback","title":"Poolder.Monitor.handle_down/2","doc":"","ref":"Poolder.Monitor.html#c:handle_down/2"},{"type":"callback","title":"Poolder.Monitor.handle_hibernate/1","doc":"","ref":"Poolder.Monitor.html#c:handle_hibernate/1"},{"type":"callback","title":"Poolder.Monitor.handle_init/1","doc":"","ref":"Poolder.Monitor.html#c:handle_init/1"},{"type":"module","title":"Poolder.Monitor.Default","doc":"","ref":"Poolder.Monitor.Default.html"},{"type":"function","title":"Poolder.Monitor.Default.child_spec/1","doc":"","ref":"Poolder.Monitor.Default.html#child_spec/1"},{"type":"function","title":"Poolder.Monitor.Default.handle_down/2","doc":"Called when a monitored process goes down.","ref":"Poolder.Monitor.Default.html#handle_down/2"},{"type":"function","title":"Poolder.Monitor.Default.handle_hibernate/1","doc":"Called when the monitor hibernates.","ref":"Poolder.Monitor.Default.html#handle_hibernate/1"},{"type":"function","title":"Poolder.Monitor.Default.handle_init/1","doc":"Called when the monitor starts.","ref":"Poolder.Monitor.Default.html#handle_init/1"},{"type":"function","title":"Poolder.Monitor.Default.loop/2","doc":"","ref":"Poolder.Monitor.Default.html#loop/2"},{"type":"function","title":"Poolder.Monitor.Default.monitor/1","doc":"","ref":"Poolder.Monitor.Default.html#monitor/1"},{"type":"function","title":"Poolder.Monitor.Default.start/1","doc":"","ref":"Poolder.Monitor.Default.html#start/1"},{"type":"function","title":"Poolder.Monitor.Default.start_link/1","doc":"","ref":"Poolder.Monitor.Default.html#start_link/1"},{"type":"behaviour","title":"Poolder.Pooler","doc":"","ref":"Poolder.Pooler.html"},{"type":"callback","title":"Poolder.Pooler.handle_init/1","doc":"","ref":"Poolder.Pooler.html#c:handle_init/1"},{"type":"behaviour","title":"Poolder.Scheduler","doc":"","ref":"Poolder.Scheduler.html"},{"type":"callback","title":"Poolder.Scheduler.handle_error/4","doc":"","ref":"Poolder.Scheduler.html#c:handle_error/4"},{"type":"callback","title":"Poolder.Scheduler.handle_hibernate/1","doc":"","ref":"Poolder.Scheduler.html#c:handle_hibernate/1"},{"type":"module","title":"Poolder.Supervisor","doc":"","ref":"Poolder.Supervisor.html"},{"type":"function","title":"Poolder.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Poolder.Supervisor.html#child_spec/1"},{"type":"function","title":"Poolder.Supervisor.start_link/2","doc":"","ref":"Poolder.Supervisor.html#start_link/2"},{"type":"module","title":"Poolder.Tasker","doc":"","ref":"Poolder.Tasker.html"},{"type":"function","title":"Poolder.Tasker.await/2","doc":"","ref":"Poolder.Tasker.html#await/2"},{"type":"function","title":"Poolder.Tasker.callback/2","doc":"","ref":"Poolder.Tasker.html#callback/2"},{"type":"function","title":"Poolder.Tasker.callback/3","doc":"","ref":"Poolder.Tasker.html#callback/3"},{"type":"function","title":"Poolder.Tasker.child_spec/1","doc":"","ref":"Poolder.Tasker.html#child_spec/1"},{"type":"function","title":"Poolder.Tasker.execute/2","doc":"","ref":"Poolder.Tasker.html#execute/2"},{"type":"function","title":"Poolder.Tasker.loop/4","doc":"","ref":"Poolder.Tasker.html#loop/4"},{"type":"function","title":"Poolder.Tasker.start/1","doc":"","ref":"Poolder.Tasker.html#start/1"},{"type":"function","title":"Poolder.Tasker.start_link/1","doc":"","ref":"Poolder.Tasker.html#start_link/1"},{"type":"function","title":"Poolder.Tasker.stop/1","doc":"","ref":"Poolder.Tasker.html#stop/1"},{"type":"behaviour","title":"Poolder.Worker","doc":"","ref":"Poolder.Worker.html"},{"type":"callback","title":"Poolder.Worker.handle_call/3","doc":"","ref":"Poolder.Worker.html#c:handle_call/3"},{"type":"callback","title":"Poolder.Worker.handle_error/4","doc":"","ref":"Poolder.Worker.html#c:handle_error/4"},{"type":"callback","title":"Poolder.Worker.handle_hibernate/1","doc":"","ref":"Poolder.Worker.html#c:handle_hibernate/1"},{"type":"callback","title":"Poolder.Worker.handle_init/1","doc":"","ref":"Poolder.Worker.html#c:handle_init/1"},{"type":"callback","title":"Poolder.Worker.handle_job/2","doc":"","ref":"Poolder.Worker.html#c:handle_job/2"},{"type":"callback","title":"Poolder.Worker.terminate/2","doc":"","ref":"Poolder.Worker.html#c:terminate/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}